@@ -10,7 +10,7 @@ pub const BLANK_INPUT: GameInput = GameInput {
     size: 0,
 };
 
-/// Computes the fletcher16 checksum, copied from wikipedia: https://en.wikipedia.org/wiki/Fletcher%27s_checksum
+/// Computes the fletcher16 checksum, copied from wikipedia: <https://en.wikipedia.org/wiki/Fletcher%27s_checksum>
 fn fletcher16(data: &[u8]) -> u16 {
     let mut sum1: u16 = 0;
     let mut sum2: u16 = 0;
@@ -20,7 +20,7 @@ fn fletcher16(data: &[u8]) -> u16 {
         sum2 = (sum2 + sum1) % 255;
     }
 
-    return (sum2 << 8) | sum1;
+    (sum2 << 8) | sum1
 }
 
 /// Represents a serialized game state of your game for a single frame. The buffer `buffer` holds your state, `frame` indicates the associated frame number
@@ -32,7 +32,7 @@ pub struct GameState {
     /// The serialized gamestate in bytes.
     pub buffer: Option<Vec<u8>>,
     /// The checksum of the gamestate.
-    pub checksum: usize,
+    pub checksum: u64,
 }
 
 impl Default for GameState {
@@ -46,16 +46,16 @@ impl Default for GameState {
 }
 
 impl GameState {
-    pub fn new(frame: Frame, buffer: Option<Vec<u8>>, check: Option<usize>) -> Self {
+    pub fn new(frame: Frame, buffer: Option<Vec<u8>>, check: Option<u64>) -> Self {
         let checksum = match check {
             Some(cs) => cs,
             None => match &buffer {
-                Some(data) => fletcher16(data) as usize,
+                Some(data) => fletcher16(data) as u64,
                 None => 0,
             },
         };
 
-        GameState {
+        Self {
             frame,
             buffer,
             checksum,
